@@ -5,7 +5,7 @@ sys.path.append(os.path.dirname(os.path.realpath(__file__)))  # enables relative
 import dataclasses
 
 #import info
-from info import platform_info
+from info_impl import PlatformInfo, platform_info
 
 
 @dataclasses.dataclass
